#ifndef EFL_GENERATED_EVAS_TEXTGRID_HH
#define EFL_GENERATED_EVAS_TEXTGRID_HH

#include <Eo.hh>

#include <eo_cxx_interop.hh>

extern "C"
{
#include "evas_textgrid.eo.h"
}

#include "evas_object.eo.hh"
#include <string>

namespace evas { 

struct textgrid
      : evas::object
{
   /// @brief Eo Constructor.
   ///
   /// Constructs the object from an Eo* pointer stealing its ownership.
   ///
   /// @param eo The Eo object pointer.
   ///
   explicit textgrid(Eo* eo)
      : evas::object(eo)
   {}

   /// @brief nullptr_t Constructor.
   ///
   /// Constructs an empty (null) object.
   ///
   explicit textgrid(std::nullptr_t)
      : evas::object(nullptr)
   {}

   textgrid(efl::eo::parent_type _p = (efl::eo::parent = nullptr))
      : textgrid(_c0(_p))
   {}

   /// @brief Copy Constructor.
   ///
   textgrid(textgrid const& other)
      : evas::object(eo_ref(other._eo_ptr()))
   {}

   ~textgrid() {}

   /// @brief @brief Indicate for evas that part of a textgrid region (cells) has been updated.
   ///
   /// This function declares to evas that a region of cells was updated by
   /// code and needs refreshing. An application should modify cells like this
   /// as an example:
   ///
   /// @code
   /// Evas_Textgrid_Cell *cells;
   /// int i;
   ///
   /// cells = evas_object_textgrid_cellrow_get(obj, row);
   /// for (i = 0; i < width; i++) cells[i].codepoint = 'E';
   /// evas_object_textgrid_cellrow_set(obj, row, cells);
   /// evas_object_textgrid_update_add(obj, 0, row, width, 1);
   /// @endcode
   ///
   /// @see evas_object_textgrid_cellrow_set()
   /// @see evas_object_textgrid_cellrow_get()
   /// @see evas_object_textgrid_size_set()
   ///
   /// @since 1.7
   ///
   /// @param x The rect region of cells top-left x (column)
   /// @param y The rect region of cells top-left y (row)
   /// @param w The rect region size in number of cells (columns)
   /// @param h The rect region size in number of cells (rows)
   ///
   void update_add(int x_, int y_, int w_, int h_) const
   {
      eo_do(_eo_ptr(), ::evas_obj_textgrid_update_add(x_, y_, w_, h_));
   }

   /// @brief @brief Set the string at the given row of the given textgrid object.
   ///
   /// This function returns cells to the textgrid taken by
   /// evas_object_textgrid_cellrow_get(). The row pointer @p row should be the
   /// same row pointer returned by evas_object_textgrid_cellrow_get() for the
   /// same row @p y.
   ///
   /// @see evas_object_textgrid_cellrow_get()
   /// @see evas_object_textgrid_size_set()
   /// @see evas_object_textgrid_update_add()
   ///
   /// @since 1.7
   ///
   /// @param y The row index of the grid.
   /// @param row The string as a sequence of #Evas_Textgrid_Cell.
   ///
   void cellrow_set(int y_, const Evas_Textgrid_Cell * row_) const
   {
      eo_do(_eo_ptr(), ::evas_obj_textgrid_cellrow_set(y_, row_));
   }

   /// @brief @brief Get the string at the given row of the given textgrid object.
   ///
   /// @return A pointer to the first cell of the given row.
   ///
   /// This function returns a pointer to the first cell of the line @p y
   /// of the textgrid object @p obj. If @p y is not between 0 and the
   /// number of lines of the grid - 1, or on error, this function return @c NULL.
   ///
   /// @see evas_object_textgrid_cellrow_set()
   /// @see evas_object_textgrid_size_set()
   /// @see evas_object_textgrid_update_add()
   ///
   /// @since 1.7
   ///
   /// @param y The row index of the grid.
   ///
   Evas_Textgrid_Cell * cellrow_get(int y_) const
   {
      Evas_Textgrid_Cell * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::evas_obj_textgrid_cellrow_get(y_));
      return _tmp_ret;
   }

   /// @brief @brief The set color to the given palette at the given index of the given textgrid object.
   ///
   /// This function sets the color for the palette of type @p pal at the
   /// index @p idx of the textgrid object @p obj. The ARGB components are
   /// given by @p r, @p g, @p b and @p a. This color can be used when
   /// setting the #Evas_Textgrid_Cell structure. The components must set
   /// a pre-multiplied color. If pal is #EVAS_TEXTGRID_PALETTE_NONE or
   /// #EVAS_TEXTGRID_PALETTE_LAST, or if @p idx is not between 0 and 255,
   /// or on error, this function does nothing. The color components are
   /// clamped between 0 and 255. If @p idx is greater than the latest set
   /// color, the colors between this last index and @p idx - 1 are set to
   /// black (0, 0, 0, 0).
   ///
   /// @see evas_object_textgrid_palette_get()
   ///
   /// @since 1.7
   ///
   /// @param pal The type of the palette to set the color.
   /// @param idx The index of the paletter to which the color is stored.
   /// @param r The red component of the color.
   /// @param g The green component of the color.
   /// @param b The blue component of the color.
   /// @param a The alpha component of the color.
   ///
   void palette_set(Evas_Textgrid_Palette pal_, int idx_, int r_, int g_, int b_, int a_) const
   {
      eo_do(_eo_ptr(), ::evas_obj_textgrid_palette_set(pal_, idx_, r_, g_, b_, a_));
   }

   /// @brief @brief The retrieve color to the given palette at the given index of the given textgrid object.
   ///
   /// This function retrieves the color for the palette of type @p pal at the
   /// index @p idx of the textgrid object @p obj. The ARGB components are
   /// stored in the buffers @p r, @p g, @p b and @p a. If @p idx is not
   /// between 0 and the index of the latest set color, or if @p pal is
   /// #EVAS_TEXTGRID_PALETTE_NONE or #EVAS_TEXTGRID_PALETTE_LAST, the
   /// values of the components are 0. @p r, @p g, @p b and @p a can be
   /// @c NULL.
   ///
   /// @see evas_object_textgrid_palette_set()
   ///
   /// @since 1.7
   ///
   /// @param pal The type of the palette to set the color.
   /// @param idx The index of the palette to which the color is stored.
   /// @param[out] r A pointer to the red component of the color.
   /// @param[out] g A pointer to the green component of the color.
   /// @param[out] b A pointer to the blue component of the color.
   /// @param[out] a A pointer to the alpha component of the color.
   ///
   void palette_get(Evas_Textgrid_Palette pal_, int idx_, int* r_, int* g_, int* b_, int* a_) const
   {
      eo_do(_eo_ptr(), ::evas_obj_textgrid_palette_get(pal_, idx_, r_, g_, b_, a_));
   }

   /// @param font_source The font file's path.
   ///
   std::string font_source_get() const
   {
      const char * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::evas_obj_textgrid_font_source_get());
      return efl::eolian::to_cxx<std::string>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param font_source The font file's path.
   ///
   void font_source_set(std::string font_source_) const
   {
      eo_do(_eo_ptr(), ::evas_obj_textgrid_font_source_set(efl::eolian::to_c(font_source_)));
   }

   /// @param styles 
   ///
   Evas_Textgrid_Font_Style supported_font_styles_get() const
   {
      Evas_Textgrid_Font_Style _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::evas_obj_textgrid_supported_font_styles_get());
      return _tmp_ret;
   }

   /// @param styles 
   ///
   void supported_font_styles_set(Evas_Textgrid_Font_Style styles_) const
   {
      eo_do(_eo_ptr(), ::evas_obj_textgrid_supported_font_styles_set(styles_));
   }

   /// @param font_name The font (family) name.
   /// @param font_size The font size, in points.
   ///
   void font_get(const char ** font_name_, Evas_Font_Size* font_size_) const
   {
      eo_do(_eo_ptr(), ::evas_obj_textgrid_font_get(font_name_, font_size_));
   }

   /// @param font_name The font (family) name.
   /// @param font_size The font size, in points.
   ///
   void font_set(std::string font_name_, Evas_Font_Size font_size_) const
   {
      eo_do(_eo_ptr(), ::evas_obj_textgrid_font_set(efl::eolian::to_c(font_name_), font_size_));
   }

   /// @param w The number of columns (width in cells) of the grid.
   /// @param h The number of rows (height in cells) of the grid.
   ///
   void size_get(int* w_, int* h_) const
   {
      eo_do(_eo_ptr(), ::evas_obj_textgrid_size_get(w_, h_));
   }

   /// @param w The number of columns (width in cells) of the grid.
   /// @param h The number of rows (height in cells) of the grid.
   ///
   void size_set(int w_, int h_) const
   {
      eo_do(_eo_ptr(), ::evas_obj_textgrid_size_set(w_, h_));
   }

   /// @param width A pointer to the location to store the width in pixels of a cell.
   /// @param height A pointer to the location to store the height in
   /// pixels of a cell.
   ///
   void cell_size_get(int* width_, int* height_) const
   {
      eo_do(_eo_ptr(), ::evas_obj_textgrid_cell_size_get(width_, height_));
   }

   static Eo_Class const* _eo_class()
   {
      return(EVAS_TEXTGRID_CLASS);
   }

private:
   static Eo* _c0(efl::eo::parent_type _p)
   {
      return eo_add_custom(EVAS_TEXTGRID_CLASS, _p._eo_raw, eo_constructor());
   }

};
} 

template <typename T>
void evas_textgrid_update_add_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, int x_, int y_, int w_, int h_)
{
   static_cast<T*>(self->this_)->update_add(x_, y_, w_, h_);
}

template <typename T>
void evas_textgrid_cellrow_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, int y_, const Evas_Textgrid_Cell * row_)
{
   static_cast<T*>(self->this_)->cellrow_set(y_, row_);
}

template <typename T>
Evas_Textgrid_Cell * evas_textgrid_cellrow_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, int y_)
{
   return static_cast<T*>(self->this_)->cellrow_get(y_);
}

template <typename T>
void evas_textgrid_palette_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_Textgrid_Palette pal_, int idx_, int r_, int g_, int b_, int a_)
{
   static_cast<T*>(self->this_)->palette_set(pal_, idx_, r_, g_, b_, a_);
}

template <typename T>
void evas_textgrid_palette_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_Textgrid_Palette pal_, int idx_, int* r_, int* g_, int* b_, int* a_)
{
   static_cast<T*>(self->this_)->palette_get(pal_, idx_, r_, g_, b_, a_);
}

template <typename T>
std::string evas_textgrid_font_source_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->font_source_get();
}

template <typename T>
void evas_textgrid_font_source_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * font_source_)
{
   static_cast<T*>(self->this_)->font_source_set(efl::eolian::to_cxx<std::string>(font_source_, std::tuple<std::false_type>()));
}

template <typename T>
Evas_Textgrid_Font_Style evas_textgrid_supported_font_styles_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->supported_font_styles_get();
}

template <typename T>
void evas_textgrid_supported_font_styles_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_Textgrid_Font_Style styles_)
{
   static_cast<T*>(self->this_)->supported_font_styles_set(styles_);
}

template <typename T>
void evas_textgrid_font_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char ** font_name_, Evas_Font_Size* font_size_)
{
   static_cast<T*>(self->this_)->font_get(font_name_, font_size_);
}

template <typename T>
void evas_textgrid_font_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * font_name_, Evas_Font_Size font_size_)
{
   static_cast<T*>(self->this_)->font_set(efl::eolian::to_cxx<std::string>(font_name_, std::tuple<std::false_type>()), font_size_);
}

template <typename T>
void evas_textgrid_size_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, int* w_, int* h_)
{
   static_cast<T*>(self->this_)->size_get(w_, h_);
}

template <typename T>
void evas_textgrid_size_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, int w_, int h_)
{
   static_cast<T*>(self->this_)->size_set(w_, h_);
}

template <typename T>
void evas_textgrid_cell_size_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, int* width_, int* height_)
{
   static_cast<T*>(self->this_)->cell_size_get(width_, height_);
}

namespace efl { namespace eo { namespace detail {

template<>
struct operations< evas::textgrid >
{
   template <typename T>
   struct type
   {
      virtual void update_add(int x_, int y_, int w_, int h_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::evas_obj_textgrid_update_add(x_, y_, w_, h_));
      }

      virtual void cellrow_set(int y_, const Evas_Textgrid_Cell * row_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::evas_obj_textgrid_cellrow_set(y_, row_));
      }

      virtual Evas_Textgrid_Cell * cellrow_get(int y_)
      {
         Evas_Textgrid_Cell * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::evas_obj_textgrid_cellrow_get(y_));
            return _tmp_ret;
      }

      virtual void palette_set(Evas_Textgrid_Palette pal_, int idx_, int r_, int g_, int b_, int a_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::evas_obj_textgrid_palette_set(pal_, idx_, r_, g_, b_, a_));
      }

      virtual void palette_get(Evas_Textgrid_Palette pal_, int idx_, int* r_, int* g_, int* b_, int* a_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::evas_obj_textgrid_palette_get(pal_, idx_, r_, g_, b_, a_));
      }

      virtual std::string font_source_get()
      {
         const char * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::evas_obj_textgrid_font_source_get());
            return efl::eolian::to_cxx<std::string>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void font_source_set(std::string font_source_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::evas_obj_textgrid_font_source_set(efl::eolian::to_c(font_source_)));
      }

      virtual Evas_Textgrid_Font_Style supported_font_styles_get()
      {
         Evas_Textgrid_Font_Style _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::evas_obj_textgrid_supported_font_styles_get());
            return _tmp_ret;
      }

      virtual void supported_font_styles_set(Evas_Textgrid_Font_Style styles_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::evas_obj_textgrid_supported_font_styles_set(styles_));
      }

      virtual void font_get(const char ** font_name_, Evas_Font_Size* font_size_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::evas_obj_textgrid_font_get(font_name_, font_size_));
      }

      virtual void font_set(std::string font_name_, Evas_Font_Size font_size_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::evas_obj_textgrid_font_set(efl::eolian::to_c(font_name_), font_size_));
      }

      virtual void size_get(int* w_, int* h_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::evas_obj_textgrid_size_get(w_, h_));
      }

      virtual void size_set(int w_, int h_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::evas_obj_textgrid_size_set(w_, h_));
      }

      virtual void cell_size_get(int* width_, int* height_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::evas_obj_textgrid_cell_size_get(width_, height_));
      }

   };
};


template<>
struct operation_description_class_size< evas::textgrid >
{
   static const int value = 14;
};

template <typename T>
int initialize_operation_description(efl::eo::detail::tag<evas::textgrid>
                                 , Eo_Op_Description* ops)
{
   (void)ops;
   ops[0].func = reinterpret_cast<void*>(& ::evas_textgrid_update_add_wrapper<T>);
   ops[0].api_func = reinterpret_cast<void*>(& ::evas_obj_textgrid_update_add);
   ops[0].op = EO_OP_OVERRIDE;
   ops[0].op_type = EO_OP_TYPE_REGULAR;
   ops[0].doc = NULL;

   ops[1].func = reinterpret_cast<void*>(& ::evas_textgrid_cellrow_set_wrapper<T>);
   ops[1].api_func = reinterpret_cast<void*>(& ::evas_obj_textgrid_cellrow_set);
   ops[1].op = EO_OP_OVERRIDE;
   ops[1].op_type = EO_OP_TYPE_REGULAR;
   ops[1].doc = NULL;

   ops[2].func = reinterpret_cast<void*>(& ::evas_textgrid_cellrow_get_wrapper<T>);
   ops[2].api_func = reinterpret_cast<void*>(& ::evas_obj_textgrid_cellrow_get);
   ops[2].op = EO_OP_OVERRIDE;
   ops[2].op_type = EO_OP_TYPE_REGULAR;
   ops[2].doc = NULL;

   ops[3].func = reinterpret_cast<void*>(& ::evas_textgrid_palette_set_wrapper<T>);
   ops[3].api_func = reinterpret_cast<void*>(& ::evas_obj_textgrid_palette_set);
   ops[3].op = EO_OP_OVERRIDE;
   ops[3].op_type = EO_OP_TYPE_REGULAR;
   ops[3].doc = NULL;

   ops[4].func = reinterpret_cast<void*>(& ::evas_textgrid_palette_get_wrapper<T>);
   ops[4].api_func = reinterpret_cast<void*>(& ::evas_obj_textgrid_palette_get);
   ops[4].op = EO_OP_OVERRIDE;
   ops[4].op_type = EO_OP_TYPE_REGULAR;
   ops[4].doc = NULL;

   ops[5].func = reinterpret_cast<void*>(& ::evas_textgrid_font_source_get_wrapper<T>);
   ops[5].api_func = reinterpret_cast<void*>(& ::evas_obj_textgrid_font_source_get);
   ops[5].op = EO_OP_OVERRIDE;
   ops[5].op_type = EO_OP_TYPE_REGULAR;
   ops[5].doc = NULL;

   ops[6].func = reinterpret_cast<void*>(& ::evas_textgrid_font_source_set_wrapper<T>);
   ops[6].api_func = reinterpret_cast<void*>(& ::evas_obj_textgrid_font_source_set);
   ops[6].op = EO_OP_OVERRIDE;
   ops[6].op_type = EO_OP_TYPE_REGULAR;
   ops[6].doc = NULL;

   ops[7].func = reinterpret_cast<void*>(& ::evas_textgrid_supported_font_styles_get_wrapper<T>);
   ops[7].api_func = reinterpret_cast<void*>(& ::evas_obj_textgrid_supported_font_styles_get);
   ops[7].op = EO_OP_OVERRIDE;
   ops[7].op_type = EO_OP_TYPE_REGULAR;
   ops[7].doc = NULL;

   ops[8].func = reinterpret_cast<void*>(& ::evas_textgrid_supported_font_styles_set_wrapper<T>);
   ops[8].api_func = reinterpret_cast<void*>(& ::evas_obj_textgrid_supported_font_styles_set);
   ops[8].op = EO_OP_OVERRIDE;
   ops[8].op_type = EO_OP_TYPE_REGULAR;
   ops[8].doc = NULL;

   ops[9].func = reinterpret_cast<void*>(& ::evas_textgrid_font_get_wrapper<T>);
   ops[9].api_func = reinterpret_cast<void*>(& ::evas_obj_textgrid_font_get);
   ops[9].op = EO_OP_OVERRIDE;
   ops[9].op_type = EO_OP_TYPE_REGULAR;
   ops[9].doc = NULL;

   ops[10].func = reinterpret_cast<void*>(& ::evas_textgrid_font_set_wrapper<T>);
   ops[10].api_func = reinterpret_cast<void*>(& ::evas_obj_textgrid_font_set);
   ops[10].op = EO_OP_OVERRIDE;
   ops[10].op_type = EO_OP_TYPE_REGULAR;
   ops[10].doc = NULL;

   ops[11].func = reinterpret_cast<void*>(& ::evas_textgrid_size_get_wrapper<T>);
   ops[11].api_func = reinterpret_cast<void*>(& ::evas_obj_textgrid_size_get);
   ops[11].op = EO_OP_OVERRIDE;
   ops[11].op_type = EO_OP_TYPE_REGULAR;
   ops[11].doc = NULL;

   ops[12].func = reinterpret_cast<void*>(& ::evas_textgrid_size_set_wrapper<T>);
   ops[12].api_func = reinterpret_cast<void*>(& ::evas_obj_textgrid_size_set);
   ops[12].op = EO_OP_OVERRIDE;
   ops[12].op_type = EO_OP_TYPE_REGULAR;
   ops[12].doc = NULL;

   ops[13].func = reinterpret_cast<void*>(& ::evas_textgrid_cell_size_get_wrapper<T>);
   ops[13].api_func = reinterpret_cast<void*>(& ::evas_obj_textgrid_cell_size_get);
   ops[13].op = EO_OP_OVERRIDE;
   ops[13].op_type = EO_OP_TYPE_REGULAR;
   ops[13].doc = NULL;

   return 0;
}
inline void
call_constructor(tag< evas::textgrid >
               , Eo* eo, Eo_Class const* cls EINA_UNUSED,
               args_class<evas::textgrid, ::std::tuple<> > const& args)
{
   (void)args;
   eo_do_super(eo, cls, ::eo_constructor());
}

inline void
call_constructor(tag< evas::textgrid >
               , Eo* eo, Eo_Class const* cls EINA_UNUSED,
               args_class<evas::textgrid, ::std::tuple<efl::eo::parent_type> > const& args)
{
   eo_do_super(eo, cls, ::eo_constructor());
   eo_do(eo, ::eo_parent_set(args.get<0>()._eo_raw));
}

template<>
struct extension_inheritance< evas::textgrid>
{
   template <typename U>
   struct type
   {
      operator evas::textgrid() const
      {
         return evas::textgrid(eo_ref(static_cast<U const*>(this)->_eo_ptr()));
      }

      void update_add(int x_, int y_, int w_, int h_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::evas_obj_textgrid_update_add(x_, y_, w_, h_));
      }

      void cellrow_set(int y_, const Evas_Textgrid_Cell * row_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::evas_obj_textgrid_cellrow_set(y_, row_));
      }

      Evas_Textgrid_Cell * cellrow_get(int y_)
      {
         Evas_Textgrid_Cell * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::evas_obj_textgrid_cellrow_get(y_));
            return _tmp_ret;
      }

      void palette_set(Evas_Textgrid_Palette pal_, int idx_, int r_, int g_, int b_, int a_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::evas_obj_textgrid_palette_set(pal_, idx_, r_, g_, b_, a_));
      }

      void palette_get(Evas_Textgrid_Palette pal_, int idx_, int* r_, int* g_, int* b_, int* a_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::evas_obj_textgrid_palette_get(pal_, idx_, r_, g_, b_, a_));
      }

      std::string font_source_get()
      {
         const char * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::evas_obj_textgrid_font_source_get());
            return efl::eolian::to_cxx<std::string>(_tmp_ret, std::tuple<std::false_type>());
      }

      void font_source_set(std::string font_source_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::evas_obj_textgrid_font_source_set(efl::eolian::to_c(font_source_)));
      }

      Evas_Textgrid_Font_Style supported_font_styles_get()
      {
         Evas_Textgrid_Font_Style _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::evas_obj_textgrid_supported_font_styles_get());
            return _tmp_ret;
      }

      void supported_font_styles_set(Evas_Textgrid_Font_Style styles_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::evas_obj_textgrid_supported_font_styles_set(styles_));
      }

      void font_get(const char ** font_name_, Evas_Font_Size* font_size_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::evas_obj_textgrid_font_get(font_name_, font_size_));
      }

      void font_set(std::string font_name_, Evas_Font_Size font_size_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::evas_obj_textgrid_font_set(efl::eolian::to_c(font_name_), font_size_));
      }

      void size_get(int* w_, int* h_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::evas_obj_textgrid_size_get(w_, h_));
      }

      void size_set(int w_, int h_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::evas_obj_textgrid_size_set(w_, h_));
      }

      void cell_size_get(int* width_, int* height_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::evas_obj_textgrid_cell_size_get(width_, height_));
      }

   };
};

inline Eo_Class const* get_eo_class(tag<evas::textgrid>)
{
   return (EVAS_TEXTGRID_CLASS);
}

} } }
#endif // EFL_GENERATED_EVAS_TEXTGRID_HH

